<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>You do not have the necessary permissions to run Stopmotion.
</source>
        <translation type="obsolete">Du har ikke de riktige rettighetene til å kjøre Stopmotion.</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="+45"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Main developers</source>
        <translation>Hovedutviklere</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>A&amp;uthors</source>
        <translation>&amp;Forfattere</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Translation</source>
        <translation>Oversettelse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Czech</source>
        <translation>Tsjekkisk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Slovenian</source>
        <translation>Slovensk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>French</source>
        <translation>Fransk</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Logo</source>
        <translation>Logo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Coordinating</source>
        <translation>Koordinering</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing</source>
        <translation>Testing</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Thanks To</source>
        <translation>&amp;Takk til</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Licence Agreement</source>
        <translation>&amp;Lisensavtale</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location line="-83"/>
        <source>This is the Stopmotion application for creating stop motion animations.</source>
        <translation>Dette er Stopmotion - et program for å lage stillbildeanimasjoner.</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Swedish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-23"/>
        <source>Contributors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CameraHandler</name>
    <message>
        <source>Camera &amp;off</source>
        <translation type="obsolete">&amp;Kamera av</translation>
    </message>
    <message>
        <source>Camera &amp;on</source>
        <translation type="obsolete">&amp;Kamera på</translation>
    </message>
</context>
<context>
    <name>DeviceTab</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/devicetab.cpp" line="+64"/>
        <location line="+293"/>
        <source>Below you can set which device Stopmotion should use for grabbing images and displaying video.</source>
        <translation>Her kan velge hva slags enhet Stopmotion skal hente bilder fra.</translation>
    </message>
    <message>
        <location line="-291"/>
        <location line="+293"/>
        <source>You can select from the auto-detected devices below or add devices yourself. It is not recommended to use devices which is not auto-detected, but feel free to do it if you are an advanced user.</source>
        <translation>Du kan velge en automatisk gjenkjent enhet, eller du kan legge til egne. Sistnevnte er imidlertid ikke å foretrekke, men du må gjerne gjøre det hvis du er en avansert bruker og vet hva du gjør.</translation>
    </message>
    <message>
        <location line="-290"/>
        <location line="+293"/>
        <source>The selected device is recognized as &lt;b&gt;$VIDEODEVICE&lt;/b&gt; under Video Import.</source>
        <translation>Den valgte enheten representerer &lt;b&gt;$VIDEODEVICE&lt;/b&gt; under innstillingene for &apos;Videoimport&apos;.</translation>
    </message>
    <message>
        <location line="-287"/>
        <location line="+291"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location line="-291"/>
        <location line="+291"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location line="-277"/>
        <location line="+280"/>
        <source>&amp;Add</source>
        <translation>&amp;Legg til</translation>
    </message>
    <message>
        <location line="-276"/>
        <location line="+277"/>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <location line="-274"/>
        <location line="+275"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location line="-271"/>
        <location line="+274"/>
        <source>Video device settings</source>
        <translation>Innstillinger for videoenhet</translation>
    </message>
    <message>
        <location line="-265"/>
        <location line="+266"/>
        <source>Video Device ($VIDEODEVICE): </source>
        <translation>Videoenhet ($VIDOEDEVICE):</translation>
    </message>
    <message>
        <source>Autodetected</source>
        <translation type="obsolete">Automatisk gjenkjent</translation>
    </message>
    <message>
        <location line="-218"/>
        <source>device</source>
        <translation>enhet</translation>
    </message>
</context>
<context>
    <name>ExportTab</name>
    <message>
        <source>Active</source>
        <translation type="obsolete">Aktiv</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/exporttab.cpp" line="+382"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location line="-299"/>
        <location line="+302"/>
        <source>&amp;Add</source>
        <translation>&amp;Legg til</translation>
    </message>
    <message>
        <location line="-298"/>
        <location line="+299"/>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <location line="-296"/>
        <location line="+297"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location line="-293"/>
        <source>Encoder settings</source>
        <translation>Instillinger for enkoder</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+286"/>
        <source>Do you want to be asked for an output file every time you choose to export?</source>
        <translation>Ønsker du å angi videofil hver gang du eksporterer?</translation>
    </message>
    <message>
        <location line="-284"/>
        <location line="+286"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location line="-281"/>
        <location line="+282"/>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <location line="-277"/>
        <location line="+278"/>
        <source>Set default output file:</source>
        <translation>Sett standard videofil:</translation>
    </message>
    <message>
        <location line="-272"/>
        <location line="+273"/>
        <source>Browse</source>
        <translation>Bla gjennom</translation>
    </message>
    <message>
        <location line="-268"/>
        <location line="+269"/>
        <source>Start encoder:</source>
        <translation>Start enkoder:</translation>
    </message>
    <message>
        <location line="-264"/>
        <location line="+265"/>
        <source>Stop encoder:</source>
        <translation>Stopp enkoder:</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Choose output file</source>
        <translation>Velg videofil</translation>
    </message>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for encoding the currently active project to a video file.&lt;/p&gt;&lt;p&gt;You can use $IMAGEPATH to represent the image path (absolute path to the directory where the images can be found). You should always use &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the output file (the videofile generated by the encoder) in the &lt;b&gt;command line&lt;/b&gt;. This is independent of how you decides to select it (select it for each export or have a default file).&lt;br&gt;&lt;/p&gt;&lt;p&gt; Example with mencoder (converting jpg to mpeg1): &lt;br&gt;mencoder mf://$IMAGEPATH/*.jpg -mf w=640:h=480:fps=12:type=jpg -ovc lavc -lavcopts vcodec=mpeg1video -oac copy -o $VIDEOFILE &lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;Under kan du sette hva slags program/prosess stopmotion skal bruke til generering av video.&lt;/p&gt;&lt;p&gt;$IMAGEPATH kan brukes til å representere katalogen hvor bildene er plassert. &lt;b&gt;$VIDEOFILE&lt;/b&gt; må alltid brukes for å representere videofilen, enten du velger å bli spurt om videofil for hver gang du eksporterer eller har satt en standardfil.&lt;br&gt;&lt;/p&gt;&lt;p&gt; Eksempel med mencoder (konverterer jpg til mpeg1): &lt;br&gt;mencoder mf://$IMAGEPATH/*.jpg -mf w=640:h=480:fps=12:type=jpg -ovc lavc -lavcopts vcodec=mpeg1video -oac copy -o $VIDEOFILE &lt;br&gt;</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Below you can set which program/process Stopmotion should use for encoding the currently active project to a video file.</source>
        <translation>Her kan du velge hva slags program Stopmotion skal bruke til å sette sammen bildene til en film.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>You should always use &lt;b&gt;$IMAGEPATH&lt;/b&gt; and &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the image path and the video file, respectively.</source>
        <translation>Du bør alltid bruke &lt;b&gt;$IMAGEPATH&lt;/b&gt; og &lt;b&gt;$VIDEOFILE&lt;/b&gt; til å representere henholdsvis bildekatalogen og video-filen.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>You can use &lt;b&gt;$FRAMERATE&lt;/b&gt; to represent the frame rate currently in use in the project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Example with mencoder (jpeg images to mpeg4 video):</source>
        <translation>Eksempel med mencoder (jpeg-bilder til mpeg4-video):</translation>
    </message>
</context>
<context>
    <name>ExternalCommand</name>
    <message>
        <location filename="../src/application/externalcommand.cpp" line="+44"/>
        <source>Input to program:</source>
        <translation>Input til program:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Submit</source>
        <translation>Send</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Output from external command</source>
        <translation>Output fra ekstern kommando</translation>
    </message>
    <message>
        <location line="+42"/>
        <location line="+3"/>
        <source>Result</source>
        <translation>Resultat</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Failed!</source>
        <translation>Feilet!</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Successful!</source>
        <translation>Suksess!</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <source>Go to home directory</source>
        <translation type="obsolete">Gå til hjemmekatalog</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="+32"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
</context>
<context>
    <name>FrameBar</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framebar/framebar.cpp" line="+194"/>
        <source>Frame number: </source>
        <translation>Bildenummer:</translation>
    </message>
</context>
<context>
    <name>FramePreferencesMenu</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="+114"/>
        <source>Add &amp;sound</source>
        <translation>Legg til &amp;lyd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Remove Sound</source>
        <translation>&amp;Fjern lyd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Change name</source>
        <translation>Skift navn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sounds:</source>
        <translation>Lyder:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Add sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;add sounds&lt;/em&gt; to the selected frame.&lt;/p&gt; &lt;p&gt;The sound will begin playing when this frame is shown and play until it is done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Legg til lyd&lt;/h4&gt;&lt;p&gt;Denne knappen kan brukes til å &lt;em&gt;legge til lyder&lt;/em&gt; til det valgte bildet.&lt;/p&gt;&lt;p&gt;Lyden vil starte å spille i det bildet vises, og vil spille inntil den er ferdig.&lt;/p&gt; </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&lt;h4&gt;Remove sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;remove&lt;/em&gt; the selected sound from this frame.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Fjern lyd&lt;/h4&gt;&lt;p&gt;Denne knappen kan brukes til å &lt;em&gt;fjerne&lt;/em&gt; den valgte lyden fra dette bildet.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Change name&lt;/h4&gt; &lt;p&gt;With this button you can change the name of the selected sound. &lt;BR&gt;The name of the sound has no other effect than making it easier work with the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Skift navn&lt;/h4&gt;&lt;p&gt;Denne knappen kan brukes til å skifte navn på den valgte lyden. &lt;BR&gt;Navnet har ingen effekt ut over at det blir enklere å holde styr på de forskjellige lydene.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&lt;h4&gt;Sounds&lt;/h4&gt; &lt;p&gt;This lists shows all the sounds connected to this frame.&lt;/p&gt;&lt;p&gt;The sounds will begin playing when this frame is shown and play until they are done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Lyder&lt;/h4&gt;&lt;p&gt;Denne listen viser alle lydene som er tilknyttet dette bildet.&lt;/p&gt;&lt;p&gt;Lydene vil starte å spille når bildet vises, og spiller inntil de er ferdige.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FrameView</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="+290"/>
        <location line="+14"/>
        <location line="+13"/>
        <location line="+25"/>
        <location line="+18"/>
        <location line="+12"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location line="-30"/>
        <location line="+18"/>
        <source>Grabbing failed. This may happen if you try
to grab from an invalid device. Please check
your grabber settings in the preferences menu.</source>
        <translation>Bildefangst feilet. Dette kan skje hvis du
prøver å fange bilde fra en ugyldig enhet.
Vennligst sjekk at preferansene er riktige.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>You have to define an image grabber to use.
This can be set in the preferences menu.</source>
        <translation>Du må velge et program som kan fange bilder.
Dette kan settes i preferanse-menyen.</translation>
    </message>
    <message>
        <location line="-68"/>
        <source>Pre poll command does not exists</source>
        <translation>Forhåndskommando eksisterer ikke</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>You do not have the given grabber installed on your system</source>
        <translation>Programmet du har satt til å fange bilder eksisterer ikke på ditt system</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>No video device selected in the preferences menu.</source>
        <translation>Ingen videoenheter er valgt i preferansemenyen.</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&amp;New Window</source>
        <translation type="obsolete">&amp;Nytt vindu</translation>
    </message>
    <message>
        <source>&amp;Open File</source>
        <translation type="obsolete">&amp;Åpne fil</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="obsolete">&amp;Print</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Lukk</translation>
    </message>
    <message>
        <source>&amp;Backward</source>
        <translation type="obsolete">&amp;Bakover</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="obsolete">&amp;Fremover</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation type="obsolete">&amp;Hjem</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation type="obsolete">Legg til bokmerke</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation type="obsolete">&amp;Gå</translation>
    </message>
    <message>
        <source>History</source>
        <translation type="obsolete">Historie</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Bokmerker</translation>
    </message>
    <message>
        <source>Backward</source>
        <translation type="obsolete">Bakover</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation type="obsolete">Fremover</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="obsolete">Hjem</translation>
    </message>
</context>
<context>
    <name>ImportTab</name>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabbing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; &lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Under kan du sette hva slags program/prosess stopmotion skal bruke til å fange bilder med.&lt;br&gt;&lt;br&gt;
&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Aktiv</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="+67"/>
        <location line="+254"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location line="-254"/>
        <location line="+254"/>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <location line="-238"/>
        <location line="+241"/>
        <source>&amp;Add</source>
        <translation>&amp;Legg til</translation>
    </message>
    <message>
        <location line="-237"/>
        <location line="+238"/>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <location line="-235"/>
        <location line="+236"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location line="-232"/>
        <location line="+234"/>
        <source>Import device settings</source>
        <translation>Innstillinger for input-enhet</translation>
    </message>
    <message>
        <location line="-225"/>
        <location line="+226"/>
        <source>Pre-poll command</source>
        <translation>Forhåndskommando</translation>
    </message>
    <message>
        <location line="-219"/>
        <location line="+220"/>
        <source>Start daemon</source>
        <translation>Start nisse</translation>
    </message>
    <message>
        <location line="-213"/>
        <location line="+214"/>
        <source>Stop daemon</source>
        <translation>Stopp nisse</translation>
    </message>
    <message>
        <location line="-272"/>
        <location line="+256"/>
        <source>Below you can set which program/process Stopmotion should use for grabbing images from the selected device.</source>
        <translation>Her kan du sette hva slags program Stopmotion skal bruke til å fange bilder fra den valgte videoenheten.</translation>
    </message>
    <message>
        <location line="-254"/>
        <location line="+256"/>
        <source>You should always use &lt;b&gt;$VIDEODEVICE&lt;/b&gt; and &lt;b&gt;$IMAGEFILE&lt;/b&gt; to represent the video device and the image file, respectively.</source>
        <translation>Du bør alltid bruke &lt;b&gt;$VIDEODEVICE&lt;/b&gt; og &lt;b&gt;$IMAGEFILE&lt;/b&gt; til å representere henholdsvis videoenheten og bildefilen.</translation>
    </message>
</context>
<context>
    <name>LanguageHandler</name>
    <message>
        <source>&amp;English</source>
        <translation type="obsolete">&amp;Engelsk</translation>
    </message>
    <message>
        <source>&lt;h4&gt;English&lt;/h4&gt; &lt;p&gt;Select this menu options to get the &lt;em&gt;English&lt;/em&gt; translation of the application.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Engelsk&lt;/h4&gt; &lt;p&gt;Dette menyvalget vil gi deg den engelske oversettingen av programmet.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Norwegian</source>
        <translation type="obsolete">&amp;Norsk</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Norwegian&lt;/h4&gt; &lt;p&gt;Select this menu options to get the &lt;em&gt;Norwegian&lt;/em&gt; translation of the application.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Norsk&lt;/h4&gt; &lt;p&gt;Dette menyvalget vil gi deg den norske oversettingen av programmet.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/application/languagehandler.cpp" line="+105"/>
        <source>English</source>
        <comment>This should be translated to the name of the language you are translating to, in that language. Example: English = Deutsch (Deutsch is &quot;German&quot; in German)</comment>
        <translation>Norsk</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>English</source>
        <translation></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Translation</source>
        <translation>&amp;Språk</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/helpbrowser.ui" line="+16"/>
        <source>Stopmotion Help Browser</source>
        <translation>Stopmotion hjelpevindu</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Backward</source>
        <translation>Bakover</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Forward</source>
        <translation>Fremover</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>MainWindowGUI</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="+153"/>
        <source>Ready to rumble ;-)</source>
        <translation>Klar til dyst ;-)</translation>
    </message>
    <message>
        <location line="+350"/>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Open</source>
        <translation>&amp;Åpne</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+279"/>
        <source>&amp;Save</source>
        <translation>&amp;Lagre</translation>
    </message>
    <message>
        <location line="-278"/>
        <source>Save &amp;As</source>
        <translation>Lagre &amp;som</translation>
    </message>
    <message>
        <source>Add &amp;Frames</source>
        <translation type="obsolete">Legg til &amp;bilde</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <location line="-135"/>
        <location line="+160"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>&amp;Undo</source>
        <translation>&amp;Angre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Re&amp;do</source>
        <translation>&amp;Gjør om</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cu&amp;t</source>
        <translation>Klipp &amp;ut</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopier</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Paste</source>
        <translation>&amp;Lim inn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Go to frame</source>
        <translation>&amp;Gå til bilde</translation>
    </message>
    <message>
        <source>Prefere&amp;nces</source>
        <translation type="obsolete">&amp;Preferanser</translation>
    </message>
    <message>
        <location line="-137"/>
        <location line="+185"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location line="-46"/>
        <source>What&apos;s &amp;This</source>
        <translation>H&amp;va er dette</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location line="-121"/>
        <location line="+120"/>
        <location line="+47"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location line="+191"/>
        <source>&lt;h4&gt;Frame preferences menu&lt;/h4&gt; &lt;p&gt;In this menu you can set preferences for the selected frame/frames, such as &lt;b&gt;subtitles&lt;/b&gt;, &lt;b&gt;sound effects&lt;/b&gt;, etc.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Bildeinnstillinger&lt;/h4&gt; &lt;p&gt;I denne menyen kan du sette innstillinger for den valgte frame slik som &lt;b&gt;undertekst&lt;/b&gt;, &lt;b&gt;lydeffekter&lt;/b&gt;, etc. &lt;/p&gt;</translation>
    </message>
    <message>
        <source>Add sound</source>
        <translation type="obsolete">Legg til lyd</translation>
    </message>
    <message>
        <source>Remove Sound</source>
        <translation type="obsolete">Fjern lyd</translation>
    </message>
    <message>
        <source>Change name</source>
        <translation type="obsolete">Skift navn</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation type="obsolete">Lyder:</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>&lt;h4&gt;Go to frame menu&lt;/h4&gt; &lt;p&gt;Here you can specify a framenumber and the program will jump to the specified frame&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Gå til bilde-menyen&lt;/h4&gt; &lt;p&gt;I denne menyen kan du angi nummeret til et bilde som programmet skal gå til.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="-226"/>
        <source>Go to frame:</source>
        <translation>Gå til frame:</translation>
    </message>
    <message>
        <source>Frame number: 0</source>
        <translation type="obsolete">Frame: 0</translation>
    </message>
    <message>
        <location line="+212"/>
        <source>&lt;h4&gt;Frame number&lt;/h4&gt;&lt;p&gt;This area displays the numberof the currently selected frame&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Bildenummer&lt;/h4&gt; &lt;p&gt;Dette feltet viser nummeret på det valgte bildet.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Unsaved changes</source>
        <translation>Ulagrede forandringer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save?</source>
        <translation>Det er forandringer som ikke har blitt lagret. Ønsker du å lagre dem nå?</translation>
    </message>
    <message>
        <location line="+133"/>
        <location line="+50"/>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <location line="-50"/>
        <location line="+50"/>
        <source>&amp;No</source>
        <translation>&amp;Nei</translation>
    </message>
    <message>
        <source>&lt;p&gt;This is the stopmotion application for creating stopmotion animations.&lt;/p&gt;&lt;p&gt;(c) 2005, Fredrik Berg Kjølstad and Bjørn Erik Nilsen&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Dette er Stopmotion-applikasjonen til å lage stop motion-animasjoner. &lt;/p&gt; &lt;p&gt;(c) 2005, Fredrik Berg Kjølstad and Bjørn Erik Nilsen&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation type="obsolete">Lagre fil</translation>
    </message>
    <message>
        <source>&amp;Thanks To</source>
        <translation type="obsolete">&amp;Takk til</translation>
    </message>
    <message>
        <source>&amp;Licence Agreement</source>
        <translation type="obsolete">&amp;Lisensavtale</translation>
    </message>
    <message>
        <location line="-376"/>
        <source>&lt;h4&gt;Open&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Opens&lt;/em&gt; a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Åpne&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Åpner&lt;/em&gt; en Stopmotion prosjektfil. &lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>&lt;h4&gt;Undo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Undoes&lt;/em&gt; your last operation. You can press undo several time to undo earlier operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Angre&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Angrer&lt;/em&gt; den siste operasjonen. Du kan trykke på angre flere ganger for å angre tidligere operasjoner. &lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;h4&gt;Redo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Redoes&lt;/em&gt; your last operation. You can press redo several times to redo several operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Gjenta&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Gjentar&lt;/em&gt; den siste operasjonen. Du kan trykke på gjenta flere ganger for gjenta flere operasjoner. &lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;h4&gt;Cut&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Cuts&lt;/em&gt; the selected frames out of the animation and adds them to the clipboard so that you can paste them in somewhere else.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Klipp&lt;/h4&gt;&lt;p&gt;&lt;em&gt;Klipper&lt;/em&gt; ut de valgte bildene til klippebrettet, slik at du kan lime dem inn et annet sted. &lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;h4&gt;Copy&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Copies&lt;/em&gt; the selected frames to the clipboard. You can then paste them in another place.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Kopier&lt;/h4&gt;&lt;p&gt;&lt;em&gt;Kopierer&lt;/em&gt; de valgte bildene til klippebrettet. Disse kan du lime inn et annet sted.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;h4&gt;Paste&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Pastes&lt;/em&gt; the frames which are currently in the clipboard into the selected location.&lt;/p&gt; &lt;p&gt;You can copy/cut images from another programs and then use this option to paste them into this animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Lim inn&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Limer inn&lt;/em&gt; bildene fra klippebrettet til den valgte plassen.&lt;/p&gt;&lt;p&gt;Du kan kopiere/klippe bilder fra andre programmer for deretter å lime dem inn i animasjonen din.&lt;/p&gt; </translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&lt;h4&gt;What&apos;s This&lt;/h4&gt; &lt;p&gt;This will give you a WhatsThis mouse cursor which can be used to bring up helpful information like this.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Hva er dette&lt;/h4&gt;&lt;p&gt; Denne vil gi deg et spørsmålstegn som musepeker. Denne kan du bruke til å finne nyttig informasjon slik som her. &lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>&lt;h4&gt;About&lt;/h4&gt; &lt;p&gt;This will display a small information box where you can read general information as well as the names of the developers behind this excellent piece of software.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Om&lt;/h4&gt;&lt;p&gt;Denne gir deg et lite vindu hvor du kan lese om generell informasjon om denne applikasjonen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>&lt;h4&gt;FrameBar&lt;/h4&gt; &lt;p&gt;In this area you can see the frames and scenes in the animations and build the animation by moving the them around.&lt;/p&gt;&lt;p&gt;You can switch to the next and the previous frame using the &lt;b&gt;arrow buttons&lt;/b&gt; or &lt;b&gt;x&lt;/b&gt; and &lt;b&gt;z&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Bilder&lt;/h4&gt;&lt;p&gt;Her kan du se alle bildene og scenene som animasjonen din består av. Disse kan du flytte rundt med musa.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>&lt;h4&gt;Tool menu&lt;/h4&gt; &lt;p&gt;This is the tool menu where most of the buttons and widgets you will need when working on stop motion animations are located.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Verktøymeny&lt;/h4&gt; &lt;p&gt;Her finner du mesteparten av verktøyene du trenger når du lager animasjonen.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Add &amp;sound</source>
        <translation type="obsolete">Legg til &amp;lyd</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>&lt;h4&gt;FrameView&lt;/h4&gt;&lt;p&gt; In this area you can see the selected frame. You can also play animations in this window by pressing the &lt;b&gt;Play&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Bildevisning&lt;/h4&gt;&lt;p&gt; I dette vinduet ser du bildet som til enhver tid er markert.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation type="obsolete">&amp;Forfattere</translation>
    </message>
    <message>
        <location line="-112"/>
        <source>&lt;h4&gt;Quit&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Quits&lt;/em&gt; the program.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Avslutt&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Avsutter&lt;/em&gt; programmet.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>&lt;h4&gt;Go to frame&lt;/h4&gt; &lt;p&gt;This will bring up a popup-menu at the bottom where you can choose a frame you want to &lt;em&gt;go to&lt;/em&gt;.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Gå til bilde&lt;/h4&gt; &lt;p&gt; Denne vil sprette opp en liten meny helt nederst hvor du kan velge et bildenummer du ønsker å gå til.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;English</source>
        <translation type="obsolete">&amp;Engelsk</translation>
    </message>
    <message>
        <source>&lt;h4&gt;English&lt;/h4&gt; &lt;p&gt;Select this menu options to get the &lt;em&gt;English&lt;/em&gt; translation of the application.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Engelsk&lt;/h4&gt; &lt;p&gt;Dette menyvalget vil gi deg den engelske oversettingen av programmet.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Norwegian</source>
        <translation type="obsolete">&amp;Norsk</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Norwegian&lt;/h4&gt; &lt;p&gt;Select this menu options to get the &lt;em&gt;Norwegian&lt;/em&gt; translation of the application.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Norsk&lt;/h4&gt; &lt;p&gt;Dette menyvalget vil gi deg den norske oversettingen av programmet.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Languages</source>
        <translation type="obsolete">&amp;Språk</translation>
    </message>
    <message>
        <location line="-292"/>
        <location line="+163"/>
        <source>&amp;Settings</source>
        <translation>I&amp;nnstillinger</translation>
    </message>
    <message>
        <source>Disable sound</source>
        <translation type="obsolete">Skru av lyd</translation>
    </message>
    <message>
        <location line="-51"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location line="-132"/>
        <location line="+172"/>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Ny&lt;/h4&gt; &lt;p&gt; Oppretter et &lt;em&gt;nytt&lt;/em&gt; prosjekt.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Lagre&lt;/h4&gt;&lt;p&gt;&lt;em&gt;Lagrer&lt;/em&gt; nåværende animasjon som en Stopmotion prosjektfil. &lt;BR&gt; Hvis prosjektet allerede er lagret til fil, vil det automatisk lagre til denne filen. &lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Lagre som&lt;/h4&gt;&lt;p&gt;&lt;em&gt;Lagrer&lt;/em&gt; nåværende animasjon som en Stopmotion prosjektfil.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Exports the current project as &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Video&lt;/h4&gt;&lt;p&gt;Eksporterer nåværende prosjekt til &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt; Instillinger for dette setter du i preferansenmenyen.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;Exports the current animation as a &lt;em&gt;Cinerella&lt;/em&gt; project.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Cinelerra&lt;/h4&gt;&lt;p&gt;Eksporterer nåværende animasjon til et &lt;em&gt;Cinelerra&lt;/em&gt;-prosjekt.&lt;/p&gt; Ikke støttet for øyeblikket.</translation>
    </message>
    <message>
        <location line="-116"/>
        <source>Cinelerra</source>
        <translation>Cinelerra</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Configure Stopmotion</source>
        <translation>&amp;Konfigurer Stopmotion</translation>
    </message>
    <message>
        <location line="-140"/>
        <location line="+772"/>
        <source>Open &amp;Recent</source>
        <translation>Åpne &amp;siste</translation>
    </message>
    <message>
        <location line="-562"/>
        <source>New project</source>
        <translation>Nytt prosjekt</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open project</source>
        <translation>Åpne prosjekt</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Save project</source>
        <translation>Lagre prosjekt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save project As</source>
        <translation>Lagre prosjekt som</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Undo</source>
        <translation>Angre</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Redo</source>
        <translation>Gjenta</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Cut</source>
        <translation>Klipp</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Go to frame</source>
        <translation>Gå til bildenummer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Configure Stopmotion&lt;/h4&gt; &lt;p&gt;This will opens a window where you can &lt;em&gt;configure&lt;/em&gt; Stopmotion with various input and output devices.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Konfigurer Stopmotion&lt;/h4&gt; &lt;p&gt;Du vil få opp et vindu hvor du kan &lt;em&gt;konfigurere&lt;/em&gt; Stopmotion med ulike inn- og utenheter.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Configure Stopmotion</source>
        <translation>Konfigurer Stopmotion</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>What&apos;s This</source>
        <translation>Hva er dette</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Do&amp;n&apos;t save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+127"/>
        <location line="+52"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location line="-51"/>
        <source>Cannot find any registered encoder to be used for
video export. This can be set in the preferences
menu. Export to video will not be possible until you
have set an encoder to use. Do you want to set it now?</source>
        <translation>Ingen registrerte enkodere for eksport til video. Dette
kan settes i preferansemenyen. Eksport til video vil ikke
være mulig før du har satt en gyldig enkoder. 
Ønsker du å sette dette nå?</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Export to video file</source>
        <translation>Eksporter til videofil</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>The registered encoder is not valid. Do you want
to check your settings in the preferences menu?</source>
        <translation>Den registrerte enkoderen er ikke gyldig. Ønsker du
å sjekke innstillingene i preferansemenyen?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Export to file</source>
        <translation>Eksporter til fil</translation>
    </message>
    <message>
        <location line="-264"/>
        <source>&lt;h4&gt;Help&lt;/h4&gt; &lt;p&gt;This button will bring up a dialog with the Stopmotion manual&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Hjelp&lt;/h4&gt;&lt;p&gt;Denne knappen viser et vindu med brukermanualen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Main developers&lt;/b&gt;&lt;br&gt;Fredrik Berg Kjølstad &amp;lt;fredrikbk@hotmail.com&amp;gt;&lt;br&gt;Bjørn Erik Nilsen &amp;lt;bjoern.nilsen@bjoernen.com&amp;gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Utviklere&lt;/b&gt;&lt;br&gt;Fredrik Berg Kjølstad &amp;lt;fredrikbk@hotmail.com&amp;gt;&lt;br&gt;Bjørn Erik Nilsen &amp;lt;bjoern.nilsen@bjoernen.com&amp;gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Stopmotion User Manual</source>
        <translation type="obsolete">Stopmotion brukermanual</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Coordinating&lt;/b&gt;&lt;br&gt;Herman Robak &amp;lt;herman@skolelinux.no&amp;gt;&lt;br&gt;Øyvind Kolås &amp;lt;pippin@gimp.org&amp;gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Testing&lt;/b&gt;&lt;br&gt;Tore Sinding Bekkedal &amp;lt;toresbe@ifi.uio.no&amp;gt;&lt;br&gt;Finn Arne Johansen &amp;lt;faj@bzz.no&amp;gt;&lt;br&gt;Halvor Borgen &amp;lt;halvor.borgen@hig.no&amp;gt;&lt;br&gt;Bjørn Are Hansen &amp;lt;post@bahansen.net&amp;gt;&lt;br&gt;John Steinar Bildøy &amp;lt;johnsbil@haldenfriskole.no&amp;gt;&lt;br&gt;Ole-Anders Andreassen &amp;lt;ole-anders.andreassen@sunndal.kommune.no&amp;gt;&lt;br&gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Translation&lt;/b&gt;&lt;br&gt;George Helebrant &amp;lt;helb@skatekralovice.com&amp;gt; (Czech)&lt;br&gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;Koordinering&lt;/b&gt;&lt;br&gt;Herman Robak &amp;lt;herman@skolelinux.no&amp;gt;&lt;br&gt;Øyvind Kolås &amp;lt;pippin@gimp.org&amp;gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Testing&lt;/b&gt;&lt;br&gt;Tore Sinding Bekkedal &amp;lt;toresbe@ifi.uio.no&amp;gt;&lt;br&gt;Finn Arne Johansen &amp;lt;faj@bzz.no&amp;gt;&lt;br&gt;Halvor Borgen &amp;lt;halvor.borgen@hig.no&amp;gt;&lt;br&gt;Bjørn Are Hansen &amp;lt;post@bahansen.net&amp;gt;&lt;br&gt;John Steinar Bildøy &amp;lt;johnsbil@haldenfriskole.no&amp;gt;&lt;br&gt;Ole-Anders Andreassen &amp;lt;ole-anders.andreassen@sunndal.kommune.no&amp;gt;&lt;br&gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Oversetting&lt;/b&gt;&lt;br&gt;George Helebrant &amp;lt;helb@skatekralovice.com&amp;gt; (Tsjekkisk)&lt;br&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="-198"/>
        <source>Frame number: </source>
        <translation>Bildenummer:</translation>
    </message>
    <message>
        <location line="+294"/>
        <source>Choose project file</source>
        <translation>Velg prosjektfil</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Save As</source>
        <translation>Lagre som</translation>
    </message>
</context>
<context>
    <name>ModelHandler</name>
    <message>
        <location filename="../src/application/modelhandler.cpp" line="+58"/>
        <source>Choose frames to add</source>
        <translation>Velg frames å legge til</translation>
    </message>
    <message>
        <location line="+121"/>
        <source>Removed the selected frame</source>
        <translation>Fjernet den valgte frame</translation>
    </message>
    <message>
        <location line="+37"/>
        <location line="+11"/>
        <location line="+17"/>
        <source>Warning</source>
        <translation type="unfinished">Advarsel</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>You do not have Gimp installed on your system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>There is no active frame to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Failed to start Gimp!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; You can also add new programs, just make sure the image is saved with the path and filename &lt;b&gt;.stopmotion/capturedfile.png&lt;/b&gt; &lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Nedenfor kan du angi hvilket program/prosess som Stopmotion skal bruke for å ta bilder fra webkameraer, etc. &lt;br&gt;&lt;br&gt;Du kan også legge til nye programmer. Bare sørg for at bildet blir lagret med stien og filnavnet &lt;b&gt;$HOME/.stopmotion/capturedfile.png&lt;/b&gt; &lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="obsolete">&amp;Legg til</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/preferencesmenu.cpp" line="+73"/>
        <location line="+46"/>
        <source>Video &amp;Import</source>
        <translation>Video&amp;import</translation>
    </message>
    <message>
        <source>&lt;p&gt;Video Export&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Video eksport&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="-37"/>
        <location line="+38"/>
        <source>Video &amp;Export</source>
        <translation>Video&amp;eksport</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Aktiv</translation>
    </message>
    <message>
        <source>Command line option</source>
        <translation type="obsolete">Kommandolinje-opsjon</translation>
    </message>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabbing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; You can also add new programs, just make sure the command line is written with file path being &lt;b&gt;&amp;lt;DEFAULTPATH&amp;gt;&lt;/b&gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Nedenfor kan du angi hvilket program/prosess som Stopmotion skal bruke for å ta bilder fra webkameraer, etc. &lt;br&gt;&lt;br&gt;Du kan også legge til nye programmer. Bare sørg for at kommandolinjen blir skrevet med filstien: &lt;b&gt;&amp;lt;DEFAULTPATH&amp;gt;&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Fjern</translation>
    </message>
    <message>
        <location line="-81"/>
        <location line="+75"/>
        <source>Apply</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <location line="-71"/>
        <location line="+72"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location line="-58"/>
        <location line="+59"/>
        <source>Preferences Menu</source>
        <translation>Preferansemeny</translation>
    </message>
    <message>
        <location line="-25"/>
        <location line="+27"/>
        <source>Video &amp;Device</source>
        <translation>&amp;Videoenhet</translation>
    </message>
</context>
<context>
    <name>QtFrontend</name>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="+192"/>
        <location line="+15"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+8"/>
        <source>Fatal</source>
        <translation>Fatal feil</translation>
    </message>
    <message>
        <location line="-84"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="obsolete">Progresjon</translation>
    </message>
    <message>
        <source>vgrabbj VGA singleshot</source>
        <translation type="obsolete">vgrabbj VGA singleshot</translation>
    </message>
    <message>
        <location line="+158"/>
        <source>vgrabbj VGA daemon</source>
        <translation>vgrabbj VGA daemon</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
        <translation>Starter vgrabbj som en nisse. Veldig kjapt.</translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Stopmotion cannot be started; it seems like it is already running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Question</source>
        <translation>Spørsmål</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="obsolete">&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="obsolete">&amp;Nei</translation>
    </message>
    <message>
        <location line="-147"/>
        <source>The simplest setting. Fairly slow</source>
        <translation>Den enkleste opsjonen. Veldig treig</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Exports from jpeg images to mpeg1 video</source>
        <translation>Eksporterer fra jpeg-bilder til mpeg1-video</translation>
    </message>
    <message>
        <location line="+87"/>
        <source>A newer version of the preferences file with few more default
values exists. Do you want to use this one? (Your old preferences
 will be saved in ~/.stopmotion/preferences.xml.OLD)</source>
        <translation>En nyere versjon av preferansefilen med flere standardvalg eksisterer.
Ønsker du å bruke denne fremfor den gamle? (Den gamle vil bli
lagret som ~/.stopmotion/preferences.xml.OLD)</translation>
    </message>
    <message>
        <location line="-78"/>
        <source>Exports from jpeg images to mpeg2 video</source>
        <translation>Eksporterer fra jpeg-bilder til mpeg2-video</translation>
    </message>
    <message>
        <location line="-232"/>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Connecting camera...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Importing frames from disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Exporting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Restoring project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving scenes to disk...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+153"/>
        <source>vgrabbj</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <source>uvccapture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Grabbing from V4L2 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+52"/>
        <location line="+9"/>
        <location line="+8"/>
        <source>Exports from jpeg images to mpeg4 video</source>
        <translation>Eksporterer fra jpeg-bilder til mpeg4-video</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>dvgrab</source>
        <translation>dvgrab</translation>
    </message>
    <message>
        <source>Grabbing from DV-cam. (EXPERIMENTAL)</source>
        <translation type="obsolete">Fanger bilder fra DV-kamera. (EKSPERIMENTELL)</translation>
    </message>
    <message>
        <location line="-9"/>
        <source>videodog singleshot</source>
        <translation>videodog enkeltbilde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Videodog.</source>
        <translation>Videodog.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Grabbing from DV-cam.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RunAnimationHandler</name>
    <message>
        <location filename="../src/application/runanimationhandler.cpp" line="+90"/>
        <source>Running animation</source>
        <translation>Kjører animasjonen</translation>
    </message>
</context>
<context>
    <name>SoundHandler</name>
    <message>
        <location filename="../src/application/soundhandler.cpp" line="+44"/>
        <source>Sounds (*.ogg)</source>
        <translation>Lyder (*.ogg)</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Sound name</source>
        <translation>Navn på lyd</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enter the name of the sound:</source>
        <translation>Angi navn på lyden:</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>Choose sound file</source>
        <translation>Velg lydfil</translation>
    </message>
</context>
<context>
    <name>ToolsMenu</name>
    <message>
        <source>&amp;Add Frames</source>
        <translation type="obsolete">&amp;Legg til bilder</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Add Frames&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Legg til bilder&lt;/h4&gt; &lt;p&gt;Med denne knappen kan du &lt;em&gt;legge til&lt;/em&gt; bilder i animasjonen.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Remove Selection</source>
        <translation type="obsolete">&amp;Fjern valgte</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Remove Selection&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Fjern valgte bilder&lt;/h4&gt; &lt;p&gt;Trykk på denne knappen for å &lt;em&gt;fjerne&lt;/em&gt; de valgte bildene fra animasjonen.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>New &amp;Scene</source>
        <translation type="obsolete">Ny &amp;scene</translation>
    </message>
    <message>
        <source>&lt;h4&gt;New Scene&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Ny Scene&lt;/h4&gt; &lt;p&gt;Med denne knappen kan du lage en ny &lt;em&gt;scene/em&gt; som legges til animasjonen&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Re&amp;move Scene</source>
        <translation type="obsolete">&amp;Fjern scene</translation>
    </message>
    <message>
        <source>Camera &amp;on</source>
        <translation type="obsolete">&amp;Kamera på</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Toggle camera on/off&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Skru kamerae av/på&lt;/h4&gt; &lt;p&gt;Med denne knappen kan du skru kameraet av og på&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Capture Frame</source>
        <translation type="obsolete">&amp;Ta bilde</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Capture Frame&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;Ta bilde&lt;/h4&gt; &lt;p&gt;Trykk på denne knappen for å ta et bilde fra kameraet ditt og legge det til animasjonen&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Number of mixes:</source>
        <translation type="obsolete">Antall bilder mikset på:</translation>
    </message>
    <message>
        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="+223"/>
        <source>FPS chooser</source>
        <translation>FPS-velger</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;FPS-velger&lt;/h4&gt; &lt;p&gt;Ved å forandre verdien i dette feltet kan du bestemme hastigheten (i bilder per sekund) animasjonen skal kjøre i.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Mix</source>
        <translation>Miks</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Diff</source>
        <translation>Forskjell</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Number of images:</source>
        <translation>Antall bilder:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Playback</source>
        <translation>Avspilling</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Per second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Per minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Per hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&lt;h4&gt;Add Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Legg til bilder (CTRL+F)&lt;/h4&gt;&lt;p&gt;Trykk på denne knappen for å &lt;em&gt;legge til&lt;/em&gt; bilder til animasjonen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Remove Selection (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Fjern valgte bilder&lt;/h4&gt;&lt;p&gt;Trykk på denne knappen for  å &lt;em&gt;fjerne&lt;/em&gt; de valgte bildene fra animasjonen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;New Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Ny scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Trykk på denne knappen for å &lt;em&gt;legge til en ny scene&lt;/em&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected scene from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Fjern scener (SHIFT+Delete)&lt;/h4&gt;&lt;p&gt;Trykk på denne knappen for å &lt;em&gt;fjerne&lt;/em&gt; de valgte scenene fra animasjonen. &lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
        <translation>&lt;h4&gt;Skru av/på kamera&lt;/h4&gt; &lt;p&gt;Trykk på denne knappen for å skru av og på kameraet&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Ta et bilde (Space)&lt;/h4&gt;&lt;p&gt;Trykk på denne knappen for å &lt;em&gt;ta et bilde&lt;/em&gt; og legge det til i animasjonen.&lt;/p&gt;
&lt;p&gt;Dette kan også gjøres ved å trykke på &lt;b&gt;space-tasten&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, thereby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Antall bilder&lt;/h4&gt;&lt;p&gt;Her kan du sette hvor mange tidligere bilder som skal brukes i den gitte modusen (enten playback eller miks).&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Spill av animasjon (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Stop animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Stopp animasjon (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Forrige bilde (J, venstre)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Neste bilde (L, høyre) &lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Previous scene (I)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Forrige scene (l)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&lt;h4&gt;Next scene (O)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Neste scene (O)&lt;/h4&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;Spill av kontinuerlig (begynn på starten igjen når animasjonen er ferdig, CTRL+L)&lt;/h4&gt;&lt;p&gt;Her kan du velge om du ønsker å spille av animasjonen kontinuerlig, eller om den skal stoppe når den er ferdig.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+85"/>
        <source>Notice</source>
        <translation>Notis</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Playback only currently works when running the grabber 
as a daemon. Go to the preferences menu (CTRL+P) to switch 
to running the image grabbing as a daemon.</source>
        <translation>Playback fungerer kun når du gjører bildefangst-programmet som 
en nisse. Gå til preferansemenyen (CTRL+P ) for å sette at 
programmet skal kjøres som en nisse.</translation>
    </message>
    <message>
        <location line="-185"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Pr sec</source>
        <translation type="obsolete">Pr sek</translation>
    </message>
    <message>
        <source>Pr min</source>
        <translation type="obsolete">Pr min</translation>
    </message>
    <message>
        <source>Pr hr</source>
        <translation type="obsolete">Pr time</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>&lt;h4&gt;Launch Gimp&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in Gimp&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on Gimp&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
